# hf_ctp_py_proxy

上期技术期货交易 api 之 python 封装，实现接口调用。支持 windows linux.

## 环境需求

- python 3.6+

## 使用说明

ctp 接口封装由 [ctp_generate](https://gitee.com/haifengat/ctp_generate) 生成

### 代码参考

[test_trade.py](test_trade.py)
